@@ -3,16 +3,16 @@
 /* Copyright (C) 2008 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -99,6 +99,15 @@ Glib::RefPtr<Icon> content_type_get_icon(const Glib::ustring& type);
  */
 bool content_type_can_be_executable(const Glib::ustring& type);
 
+/** Tries to find a content type based on the mime type name.
+ *
+ * @param mime_type a mime type string.
+ * @returns string with content type or empty when it does not know.
+ *
+ * @newin{2,20}
+ */
+Glib::ustring content_type_from_mime_type(const Glib::ustring& mime_type);
+
 /**
  * Guesses the content type based on example data. If the function is uncertain,
  * @a result_uncertain will be set to true
@@ -140,7 +149,7 @@ Glib::ustring content_type_guess(const std::string& filename,
  * @param root The root of the tree to guess a type for.
  * @return List of zero or more content types.
  *
- * @newin2p18
+ * @newin{2,18}
  */
 Glib::StringArrayHandle content_type_guess_for_tree(const Glib::RefPtr<const File>& root);
 
